<?php

/*
 * This file is part of Twig.
 *
 * (c) Fabien Potencier
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PodlovePublisher_Vendor\Twig\NodeVisitor;

use PodlovePublisher_Vendor\Twig\Environment;
use PodlovePublisher_Vendor\Twig\Node\CheckSecurityNode;
use PodlovePublisher_Vendor\Twig\Node\CheckToStringNode;
use PodlovePublisher_Vendor\Twig\Node\Expression\Binary\ConcatBinary;
use PodlovePublisher_Vendor\Twig\Node\Expression\Binary\RangeBinary;
use PodlovePublisher_Vendor\Twig\Node\Expression\FilterExpression;
use PodlovePublisher_Vendor\Twig\Node\Expression\FunctionExpression;
use PodlovePublisher_Vendor\Twig\Node\Expression\GetAttrExpression;
use PodlovePublisher_Vendor\Twig\Node\Expression\NameExpression;
use PodlovePublisher_Vendor\Twig\Node\ModuleNode;
use PodlovePublisher_Vendor\Twig\Node\Node;
use PodlovePublisher_Vendor\Twig\Node\PrintNode;
use PodlovePublisher_Vendor\Twig\Node\SetNode;
/**
 * @author Fabien Potencier <fabien@symfony.com>
 */
final class SandboxNodeVisitor extends \PodlovePublisher_Vendor\Twig\NodeVisitor\AbstractNodeVisitor
{
    private $inAModule = \false;
    private $tags;
    private $filters;
    private $functions;
    private $needsToStringWrap = \false;
    protected function doEnterNode(\PodlovePublisher_Vendor\Twig\Node\Node $node, \PodlovePublisher_Vendor\Twig\Environment $env)
    {
        if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\ModuleNode) {
            $this->inAModule = \true;
            $this->tags = [];
            $this->filters = [];
            $this->functions = [];
            return $node;
        } elseif ($this->inAModule) {
            // look for tags
            if ($node->getNodeTag() && !isset($this->tags[$node->getNodeTag()])) {
                $this->tags[$node->getNodeTag()] = $node;
            }
            // look for filters
            if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\Expression\FilterExpression && !isset($this->filters[$node->getNode('filter')->getAttribute('value')])) {
                $this->filters[$node->getNode('filter')->getAttribute('value')] = $node;
            }
            // look for functions
            if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\Expression\FunctionExpression && !isset($this->functions[$node->getAttribute('name')])) {
                $this->functions[$node->getAttribute('name')] = $node;
            }
            // the .. operator is equivalent to the range() function
            if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\Expression\Binary\RangeBinary && !isset($this->functions['range'])) {
                $this->functions['range'] = $node;
            }
            if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\PrintNode) {
                $this->needsToStringWrap = \true;
                $this->wrapNode($node, 'expr');
            }
            if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\SetNode && !$node->getAttribute('capture')) {
                $this->needsToStringWrap = \true;
            }
            // wrap outer nodes that can implicitly call __toString()
            if ($this->needsToStringWrap) {
                if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\Expression\Binary\ConcatBinary) {
                    $this->wrapNode($node, 'left');
                    $this->wrapNode($node, 'right');
                }
                if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\Expression\FilterExpression) {
                    $this->wrapNode($node, 'node');
                    $this->wrapArrayNode($node, 'arguments');
                }
                if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\Expression\FunctionExpression) {
                    $this->wrapArrayNode($node, 'arguments');
                }
            }
        }
        return $node;
    }
    protected function doLeaveNode(\PodlovePublisher_Vendor\Twig\Node\Node $node, \PodlovePublisher_Vendor\Twig\Environment $env)
    {
        if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\ModuleNode) {
            $this->inAModule = \false;
            $node->getNode('constructor_end')->setNode('_security_check', new \PodlovePublisher_Vendor\Twig\Node\Node([new \PodlovePublisher_Vendor\Twig\Node\CheckSecurityNode($this->filters, $this->tags, $this->functions), $node->getNode('display_start')]));
        } elseif ($this->inAModule) {
            if ($node instanceof \PodlovePublisher_Vendor\Twig\Node\PrintNode || $node instanceof \PodlovePublisher_Vendor\Twig\Node\SetNode) {
                $this->needsToStringWrap = \false;
            }
        }
        return $node;
    }
    private function wrapNode(\PodlovePublisher_Vendor\Twig\Node\Node $node, string $name)
    {
        $expr = $node->getNode($name);
        if ($expr instanceof \PodlovePublisher_Vendor\Twig\Node\Expression\NameExpression || $expr instanceof \PodlovePublisher_Vendor\Twig\Node\Expression\GetAttrExpression) {
            $node->setNode($name, new \PodlovePublisher_Vendor\Twig\Node\CheckToStringNode($expr));
        }
    }
    private function wrapArrayNode(\PodlovePublisher_Vendor\Twig\Node\Node $node, string $name)
    {
        $args = $node->getNode($name);
        foreach ($args as $name => $_) {
            $this->wrapNode($args, $name);
        }
    }
    public function getPriority()
    {
        return 0;
    }
}
@\class_alias('PodlovePublisher_Vendor\\Twig\\NodeVisitor\\SandboxNodeVisitor', 'PodlovePublisher_Vendor\\Twig_NodeVisitor_Sandbox');
